@@ -1,6 +1,8 @@
 import json
 from typing import Optional, Union, Dict
 
+from typing_extensions import Literal
+
 from google.cloud.pubsub_v1 import PublisherClient as GooglePubSubClient
 from arcane.firebase import generate_token
 from google.oauth2 import service_account
@@ -40,7 +42,7 @@ class Client(GooglePubSubClient):
                                     monitoring_id: str,
                                     step: str,
                                     entity_id: str,
-                                    status: str,
+                                    status: Literal['start', 'done', 'error'],
                                     error_message: Optional[str] = None):
         """ publish a message for product flow monitoring"""
 
